
const { trimAndRemoveEmptyLines, createLines, shields } = require('./util')
const toCamelCase = require('to-camel-case')
const mdu = require('markdown-utils')

const createReadme = (config) => {
  return createLines(
    mdu.h1(config.name),
    mdu.blockquote(config.description),
    [
      mdu.badge(
        'build status',
        shields(`travis/${config.author.username}/${config.name}.svg`),
        `https://travis-ci.org/${config.author.username}/${config.name}`
      ),

      mdu.badge(
        'npm version',
        shields(`npm/v/${config.name}.svg`),
        `https://npmjs.org/package/${config.name}`
      ),

      mdu.badge(
        'dependency status',
        shields(`david/${config.name}.svg`),
        `https://david-dm.org/${config.author.username}/${config.name}`
      ),

      mdu.badge(
        'license',
        shields(`npm/l/${config.name}.svg`),
        './license'
      ),

      mdu.badge(
        'code style: standard',
        shields(`badge/code-standard-brightgreen.svg`),
        'https://github.com/feross/standard'
      )
    ],

    mdu.h2('Installation'),
    mdu.gfm(`$ npm install ${config.name}`, 'bash'),

    mdu.h2('Example'),
    mdu.gfm(trimAndRemoveEmptyLines(`
      const ${toCamelCase(config.name)} = require('${config.name}')
    `), 'js'),

    mdu.h2('Tests'),
    mdu.gfm(`$ npm test `, 'bash'),

    mdu.h2('License'),
    mdu.link(config.license, './license')
  )
}

module.exports = createReadme