
const createPackageJson = require('./create-package-json')
const { readFileSync, writeFileSync } = require('fs')
const createLicense = require('./create-license')
const createReadme = require('./create-readme')
const createSource = require('./create-source')
const createTest = require('./create-test')
const { mkdirp } = require('./util')
const { join } = require('path')

const static = (file) => readFileSync(join(__dirname, 'static', file), 'utf-8')

const assemble = (root, config) => {
  const files = [
    { path: 'package.json', contents: createPackageJson(config) },
    { path: 'readme.md', contents: createReadme(config) },
    { path: 'license', contents: createLicense(config) },
    { path: '.gitignore', contents: static('gitignore.txt')},
    { path: '.gitattributes', contents: static('gitattributes.txt')},
    { path: '.npmignore', contents: static('npmignore.txt') },
    { path: '.travis.yml', contents: static('travis.yml')},
    { path: 'src/index.js', contents: createSource(config) },
    { path: 'test/index.js', contents: createTest(config) },
  ]

  files.forEach(({ path, contents }) => {
    const fullPath = join(root, path)
    mkdirp(fullPath)
    writeFileSync(fullPath, contents)
  })
}

module.exports = assemble